#!/usr/bin/env python
# Copyright (c) 2003 by Intevation GmbH
# Authors:
# Jan-Oliver Wagner <jan@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING for details.

__version__ = "$Revision: 1.1 $"
# $Source: /greaterrepository/greater-pre-processing/add-downsegments.py,v $
# $Id: add-downsegments.py,v 1.1 2003/02/05 11:34:52 jan Exp $

def add_downsegments(src_lines):
    """Add the down1, down2 segment information to the given lines
    and return the new lines.
    Assume columns are defined as
        StretchID,type,IsDisch,up1,up2,rivclass,QMean,Q5,vMean,v5,
        RealLength,depthMean,depth5,Name
    Add them after the fifth column.
    Aferwards columns are:
        StretchID,type,IsDisch,up1,up2,down1,down2,rivclass,QMean,Q5,
        vMean,v5,RealLength,depthMean,depth5,Name
    """
    result_lines = []

    down = {}
    for line in src_lines:
        if line[0] == '#': continue
        line = line.rstrip()
        fields = line.split(',')
        if fields[3] != '0': # up1 <> 0 ?
            if not down.has_key(fields[3]):
                down[fields[3]] = [ fields[0] ]
            else:
                down[fields[3]].append(fields[0])
        if fields[4] != '0' and fields[1] != '-2': # up1 <> 0 and not
                                                   # a bifurcation?
            if not down.has_key(fields[4]):
                down[fields[4]] = [ fields[0] ]
            else:
                down[fields[4]].append(fields[0])

    # only one stretch is now missing: the most downstream one
    for line in src_lines:
        if line[0] == '#': continue
        line = line.rstrip()
        fields = line.split(',')
        if not down.has_key(fields[0]):
            down[fields[0]] = []

    result_lines.append('#StretchID,type,IsDisch,up1,up2,down1,down2,'
                        'rivclass,QMean,Q5,vMean,v5,RealLength,depthMean,'
                        'depth5,Name')

    for line in src_lines:
        if line[0] == '#': continue
        line = line.rstrip()
        fields = line.split(',')

        if len(down[fields[0]]) == 2:
            down1 = down[fields[0]][0]
            down2 = down[fields[0]][1]
        elif len(down[fields[0]]) == 1:
            down1 = down[fields[0]][0]
            down2 = '0'
        else:
            down1 = '0'
            down2 = '0'

        result_line = fields[0] + ',' + fields[1] + ',' + fields[2] + ',' + \
                      fields[3] + ',' + fields[4] + ',' + down1 + ',' + \
                      down2 + ',' + fields[5] + ',' + fields[6] + ',' + \
                      fields[7] + ',' + fields[8] + ',' + fields[9] + ',' + \
                      fields[10] + ',' + fields[11] + ',' + fields[12] + ',' + \
                      fields[13]
        result_lines.append(result_line)
    return result_lines

if __name__ == '__main__':
    river_att = open('river.att', 'r').readlines()

    new_river_att = add_downsegments(river_att)

    for line in new_river_att:
        print line
